@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -30,7 +30,7 @@ class SmtpConfigDialog : public QDialog
     Q_OBJECT
 public:
     explicit SmtpConfigDialog(Transport *transport, QWidget *parent = nullptr);
-    virtual ~SmtpConfigDialog();
+    ~SmtpConfigDialog() override;
 
 private:
     void okClicked();
